@@ -13,8 +13,8 @@ Usage::
 """
 from typing import Any, Dict, Type
 
+from boto3.botocore_stubs import ClientError as BotocoreClientError
 from botocore.client import ClientMeta
-from botocore.exceptions import ClientError as Boto3ClientError
 
 from mypy_boto3_outposts.type_defs import (
     CreateOutpostOutputTypeDef,
@@ -28,17 +28,17 @@ __all__ = ("OutpostsClient",)
 
 
 class Exceptions:
-    AccessDeniedException: Type[Boto3ClientError]
-    ClientError: Type[Boto3ClientError]
-    InternalServerException: Type[Boto3ClientError]
-    NotFoundException: Type[Boto3ClientError]
-    ServiceQuotaExceededException: Type[Boto3ClientError]
-    ValidationException: Type[Boto3ClientError]
+    AccessDeniedException: Type[BotocoreClientError]
+    ClientError: Type[BotocoreClientError]
+    InternalServerException: Type[BotocoreClientError]
+    NotFoundException: Type[BotocoreClientError]
+    ServiceQuotaExceededException: Type[BotocoreClientError]
+    ValidationException: Type[BotocoreClientError]
 
 
 class OutpostsClient:
     """
-    [Outposts.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/outposts.html#Outposts.Client)
+    [Outposts.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/outposts.html#Outposts.Client)
     """
 
     meta: ClientMeta
@@ -46,7 +46,7 @@ class OutpostsClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/outposts.html#Outposts.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/outposts.html#Outposts.Client.can_paginate)
         """
 
     def create_outpost(
@@ -58,17 +58,17 @@ class OutpostsClient:
         AvailabilityZoneId: str = None,
     ) -> CreateOutpostOutputTypeDef:
         """
-        [Client.create_outpost documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/outposts.html#Outposts.Client.create_outpost)
+        [Client.create_outpost documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/outposts.html#Outposts.Client.create_outpost)
         """
 
     def delete_outpost(self, OutpostId: str) -> Dict[str, Any]:
         """
-        [Client.delete_outpost documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/outposts.html#Outposts.Client.delete_outpost)
+        [Client.delete_outpost documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/outposts.html#Outposts.Client.delete_outpost)
         """
 
     def delete_site(self, SiteId: str) -> Dict[str, Any]:
         """
-        [Client.delete_site documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/outposts.html#Outposts.Client.delete_site)
+        [Client.delete_site documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/outposts.html#Outposts.Client.delete_site)
         """
 
     def generate_presigned_url(
@@ -79,29 +79,29 @@ class OutpostsClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/outposts.html#Outposts.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/outposts.html#Outposts.Client.generate_presigned_url)
         """
 
     def get_outpost(self, OutpostId: str) -> GetOutpostOutputTypeDef:
         """
-        [Client.get_outpost documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/outposts.html#Outposts.Client.get_outpost)
+        [Client.get_outpost documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/outposts.html#Outposts.Client.get_outpost)
         """
 
     def get_outpost_instance_types(
         self, OutpostId: str, NextToken: str = None, MaxResults: int = None
     ) -> GetOutpostInstanceTypesOutputTypeDef:
         """
-        [Client.get_outpost_instance_types documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/outposts.html#Outposts.Client.get_outpost_instance_types)
+        [Client.get_outpost_instance_types documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/outposts.html#Outposts.Client.get_outpost_instance_types)
         """
 
     def list_outposts(
         self, NextToken: str = None, MaxResults: int = None
     ) -> ListOutpostsOutputTypeDef:
         """
-        [Client.list_outposts documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/outposts.html#Outposts.Client.list_outposts)
+        [Client.list_outposts documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/outposts.html#Outposts.Client.list_outposts)
         """
 
     def list_sites(self, NextToken: str = None, MaxResults: int = None) -> ListSitesOutputTypeDef:
         """
-        [Client.list_sites documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/outposts.html#Outposts.Client.list_sites)
+        [Client.list_sites documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/outposts.html#Outposts.Client.list_sites)
         """
